@@ -1,22 +1,27 @@
-# Copyright (C) 2018 Ioannis Kosmidis
+# Copyright (C) 2018- Ioannis Kosmidis
 
-#' Subset a \code{\link{cranly_network}} according to author, package and/or directive
+#' Subset a [`cranly_network`] according to author, package and/or directive
 #'
-#' @param x a \code{\link{cranly_network}} object
-#' @param package a vector of character strings with the package names to be matched. Default is \code{Inf} which returns all available packages in \code{x} for further subsetting
-#' @param author a vector of character strings with the author names to be matched. Default is \code{Inf} which returns all available author in \code{x} for further subsetting
-#' @param directive a vector of at least one of \code{"Imports"}, \code{"Suggests"}, \code{"Enhances"}, \code{"Depends"}
-#' @param base logical. Should we include base packages in the subset? Default is \code{TRUE}
-#' @param recommended  logical. Should we include recommended packages in the subset? Default is \code{TRUE}
-#' @param exact logical. Should we use exact matching? Default is \code{TRUE}
-#' @param only logical. If \code{TRUE} the subset includes only the edges between packages named in \code{package} and/or authors named in \code{author}. If \code{FALSE} (default) edges to and from all other packages and/or authors that are linked to \code{package} and/or \code{author} are included in the subset
-#' @param ... currently not used
+#' @param x a  [`cranly_network`] object.
+#' @param package a vector of character strings with the package names to be matched. Default is [`Inf`] which returns all available packages in `x` for further subsetting.
+#' @param author a vector of character strings with the author names to be matched. Default is `Inf` which returns all available author in `x` for further subsetting.
+#' @param maintainer a vector of character strings with the maintainer names to be matched. Default is `Inf` which returns all available maintainers in `x` for further subsetting.
+#' @param directive a vector of at least one of `"Imports"`, `"Suggests"`, `"Enhances"`, `"Depends"`.
+#' @param base logical. Should we include base packages in the subset? Default is `TRUE`.
+#' @param recommended  logical. Should we include recommended packages in the subset? Default is `TRUE`.
+#' @param exact logical. Should we use exact matching? Default is `TRUE`.
+#' @param only logical. If `TRUE` the subset includes only the edges between packages named in `package` and/or authors named in `author`. If `FALSE` (default) edges to and from all other packages and/or authors that are linked to `package` and/or `author` are included in the subset.
+#' @param ... currently not used.
 #'
+#' @return
+#' A [`cranly_network`] object that is the subject of `x`.
+#' 
 #' @export
 subset.cranly_network <- function(x,
                                   package = Inf,
                                   author = Inf,
-                                  directive = c("imports", "suggests", "enhances", "depends", "linkingto"),
+                                  maintainer = Inf,
+                                  directive = c("imports", "suggests", "enhances", "depends", "linking_to"),
                                   base = TRUE,
                                   recommended = TRUE,
                                   exact = TRUE,
@@ -31,9 +36,15 @@ subset.cranly_network <- function(x,
         base_packages <- subset(x$nodes, priority == "base")$package
         recommended_packages <- subset(x$nodes, priority == "recommended")$package
 
-        ## keep <- unique(c(p1, p2))
         keep <- intersect(p1, p2)
+        
+        if (!is.infinite(maintainer)) {
+            p3 <- maintained_by(x, author = maintainer, exact = exact)
+            keep <- intersect(keep, p3)
+        }
 
+        
+        
         if (only) {
             inds <- with(x$edges, (to %in% keep & from %in% keep) &
                                   (type %in% directive))
@@ -51,13 +62,18 @@ subset.cranly_network <- function(x,
         node_names <- unique(c(as.character(edges_subset$from), as.character(edges_subset$to), keep))
         nodes_subset <- subset(x$nodes, package %in% node_names)
     }
-    else {
+    else {        
         a1 <- author_with(x, name = author, exact = exact)
         a2 <- author_of(x, package = package, exact = exact)
-
-        ## keep <- unique(c(a1, a2))
+        
         keep <- intersect(a1, a2)
 
+        if (!is.infinite(maintainer)) {
+            a3 <- maintainer_of(x, package = package, exact = exact)
+            keep <- intersect(keep, a3)
+        }
+
+
         if (only) {
             edges_subset <- subset(x$edges, (to %in% keep & from %in% keep))
         }
